@@ -153,17 +153,17 @@ pub fn render(
         throughput,
     } = config;
     let config = draw::Options {
-        output_is_terminal,
+        level_filter,
         terminal_dimensions,
+        keep_running_if_progress_is_empty,
+        output_is_terminal,
         colored,
         timestamp,
-        keep_running_if_progress_is_empty,
-        level_filter,
         hide_cursor,
     };
 
     let (event_send, event_recv) = std::sync::mpsc::sync_channel::<Event>(1);
-    let show_cursor = possibly_hide_cursor(&mut out, event_send.clone(), hide_cursor);
+    let show_cursor = possibly_hide_cursor(&mut out, event_send.clone(), hide_cursor && output_is_terminal);
     static SHOW_PROGRESS: AtomicBool = AtomicBool::new(false);
 
     let handle = std::thread::spawn({
